[Asterisk-code-review] spelling: only (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:13:22 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/17067 )


Change subject: spelling: only
......................................................................

spelling: only

Change-Id: Ic938737d7ab999b9bedf670070bac9d427fcb3ad
---
M include/asterisk/bridge.h
M main/bridge.c
M main/bridge_channel.c
M main/translate.c
M res/res_pjsip.c
5 files changed, 10 insertions(+), 10 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/67/17067/1

diff --git a/include/asterisk/bridge.h b/include/asterisk/bridge.h
index fa2e251..99a9af6 100644
--- a/include/asterisk/bridge.h
+++ b/include/asterisk/bridge.h
@@ -382,7 +382,7 @@
 	/*! Number of active channels in the bridge. */
 	unsigned int num_active;
 	/*! Number of channels with AST_BRIDGE_CHANNEL_FLAG_LONELY in the bridge. */
-	unsigned int num_lonely;
+	unsigned int num_lonly;
 	/*!
 	 * \brief Count of the active temporary requests to inhibit bridge merges.
 	 * Zero if merges are allowed.
diff --git a/main/bridge.c b/main/bridge.c
index b58364a..a01e119 100644
--- a/main/bridge.c
+++ b/main/bridge.c
@@ -1127,7 +1127,7 @@
 		AST_LIST_INSERT_TAIL(&dummy_bridge.channels, bridge_channel, entry);
 		dummy_bridge.num_channels++;
 		if (ast_test_flag(&bridge_channel->features->feature_flags, AST_BRIDGE_CHANNEL_FLAG_LONELY)) {
-			dummy_bridge.num_lonely++;
+			dummy_bridge.num_lonly++;
 		}
 		if (!bridge_channel->suspended) {
 			dummy_bridge.num_active++;
@@ -1147,7 +1147,7 @@
 		AST_LIST_INSERT_TAIL(&bridge->channels, bridge_channel, entry);
 		dummy_bridge.num_channels--;
 		if (ast_test_flag(&bridge_channel->features->feature_flags, AST_BRIDGE_CHANNEL_FLAG_LONELY)) {
-			dummy_bridge.num_lonely--;
+			dummy_bridge.num_lonly--;
 		}
 		if (!bridge_channel->suspended) {
 			dummy_bridge.num_active--;
diff --git a/main/translate.c b/main/translate.c
index 27e73f6..8a08267 100644
--- a/main/translate.c
+++ b/main/translate.c
@@ -755,7 +755,7 @@
  * dst formats.
  *
  * \note This function allows older translators built before the translation cost
- * changed away from using onely computational time to continue to be registered
+ * changed away from using only computational time to continue to be registered
  * correctly.  It is expected that translators built after the introduction of this
  * function will manually assign their own table cost value.
  *
diff --git a/res/res_pjsip.c b/res/res_pjsip.c
index c6de853..893431f 100644
--- a/res/res_pjsip.c
+++ b/res/res_pjsip.c
@@ -279,7 +279,7 @@
 						codec_prefs_incoming_answer = keep: first
 						</example>
 						<para>
-						Use the defaults but keep oinly the first codec.
+						Use the defaults but keep only the first codec.
 						</para>
 					</description>
 				</configOption>
@@ -337,7 +337,7 @@
 						codec_prefs_incoming_answer = keep: first
 						</example>
 						<para>
-						Use the defaults but keep oinly the first codec.
+						Use the defaults but keep only the first codec.
 						</para>
 					</description>
 				</configOption>

diff --git a/main/bridge_channel.c b/main/bridge_channel.c
index 012d2ef..ea77bfb 100644
--- a/main/bridge_channel.c
+++ b/main/bridge_channel.c
@@ -2163,11 +2163,11 @@
 		break;
 	}
 
-	if (bridge->num_lonely && bridge->num_lonely == bridge->num_channels) {
+	if (bridge->num_lonly && bridge->num_lonly == bridge->num_channels) {
 		/*
 		 * This will start a chain reaction where each channel leaving
 		 * enters this function and causes the next to leave as long as
 		 * there aren't non-lonely channels in the bridge.
 		 */
 		ast_bridge_channel_leave_bridge(AST_LIST_FIRST(&bridge->channels),
 			BRIDGE_CHANNEL_STATE_END_NO_DISSOLVE,
@@ -2208,7 +2208,7 @@
 		--bridge->num_active;
 	}
 	if (ast_test_flag(&bridge_channel->features->feature_flags, AST_BRIDGE_CHANNEL_FLAG_LONELY)) {
-		--bridge->num_lonely;
+		--bridge->num_lonly;
 	}
 	--bridge->num_channels;
 	AST_LIST_REMOVE(&bridge->channels, bridge_channel, entry);
@@ -2283,7 +2283,7 @@
 	AST_LIST_INSERT_TAIL(&bridge->channels, bridge_channel, entry);
 	++bridge->num_channels;
 	if (ast_test_flag(&bridge_channel->features->feature_flags, AST_BRIDGE_CHANNEL_FLAG_LONELY)) {
-		++bridge->num_lonely;
+		++bridge->num_lonly;
 	}
 	if (!bridge_channel->suspended) {
 		++bridge->num_active;
@@ -2163,11 +2163,11 @@
 		 * This will start a chain reaction where each channel leaving
 		 * enters this function and causes the next to leave as long as
-		 * there aren't non-lonely channels in the bridge.
+		 * there aren't non-lonly channels in the bridge.
 		 */
 		ast_bridge_channel_leave_bridge(AST_LIST_FIRST(&bridge->channels),
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17067
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: Ic938737d7ab999b9bedf670070bac9d427fcb3ad
Gerrit-Change-Number: 17067
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/635b4637/attachment-0001.html>


More information about the asterisk-code-review mailing list